//*****************************************************************************
//	
//	Copyright 2011 by WinSystems Inc.
//
//	Permission is hereby granted to the purchaser of WinSystems GPIO cards 
//	and CPU products incorporating a GPIO device, to distribute any binary 
//	file or files compiled using this source code directly or in any work 
//	derived by the user from this file. In no case may the source code, 
//	original or derived from this file, be distributed to any third party 
//	except by explicit permission of WinSystems. This file is distributed 
//	on an "As-is" basis and no warranty as to performance or fitness of pur-
//	poses is expressed or implied. In no case shall WinSystems be liable for 
//	any direct or indirect loss or damage, real or consequential resulting 
//	from the usage of this source code. It is the user's sole responsibility 
//	to determine fitness for any considered purpose.
//
//*****************************************************************************
//
//	Name	 : pulse.c
//
//	Project	 : PCM-VDX PWM Sample Application Program
//
//	Author	 : Paul DeMetrotion
//
//*****************************************************************************
//
//	  Date		Revision	                Description
//	--------	--------	---------------------------------------------
//	05/11/11	  1.00		Original Release
//
//*****************************************************************************

// Include some standard header files
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

// Include the WinSystems PCM-VDX definitions
#include "pcmvdxpwm.h"

int main(int argc, char *argv[])
{
	unsigned int pwm_base_addr = 0x1200;
	unsigned int channel;
	int i;

	if(argc != 2)
	{
		printf("\nUsage: %s <channel> \n", argv[0]);
		return 1;
	}
	else
	{
		printf("Test to verify proper PCM-VDX PWM operation\n");
		channel = atoi(argv[1]);
	}

	// set pwm clock to 10 MHz
	ioctl_pwm_clk_sel(PWM_10MHZ);

	// set pwm on channel
	ioctl_enab_pwm(channel, 0xFA, 0xFA);	// 20 kHz 50% DC
	printf("Channel %d  -> 20 kHz Waveform, 50%% DC\n", channel);
	usleep(10000000);
	
	ioctl_enab_pwm(channel, 0x7D, 0x177);	// 20 kHz 75% DC
	printf("Channel %d  -> 20 kHz Waveform, 75%% DC\n", channel);
	usleep(10000000);

	ioctl_enab_pwm(channel, 0x2710, 0x2710);	// 500 Hz 50% DC
	printf("Channel %d  -> 500 Hz Waveform, 50%% DC\n", channel);
	usleep(10000000);
	
	ioctl_enab_pwm(channel, 0x3A98, 0x1388);	// 500 Hz 25% DC
	printf("Channel %d  -> 500 Hz Waveform, 25%% DC\n", channel);
	usleep(10000000);
	
	ioctl_disab_pwm(channel);	// no signal
	printf("Channel %d  -> No Signal\n", channel);
	usleep(10000000);
	
	// set pwm clock to 50 MHz
	ioctl_pwm_clk_sel(PWM_50MHZ);

	// set repeat pwm on channel
	for (i = 0; i <= 25; i++)
	{
		ioctl_enab_pwm_rc(channel, 0xA, 0xA, (unsigned long) i);	// 2.5 MHz 50% DC
		printf("Channel %d -> %d pulses, 2.5 MHz Waveform, 50%% DC\n", channel, i);
		usleep(1000000);
	}

	return 0;
}
